[![Chai Documentation](http://chaijs.com/public/img/chai-logo.png)](http://chaijs.com)

Chai is a BDD / TDD assertion library for [node](http://nodejs.org) and the browser that
can be delightfully paired with any javascript testing framework.

For more information or to download plugins, view the [documentation](http://chaijs.com).

[![Build Status](https://travis-ci.org/chaijs/chai.png?branch=master)](https://travis-ci.org/chaijs/chai)

[![Selenium Test Status](https://saucelabs.com/browser-matrix/chaijs.svg)](https://saucelabs.com/u/chaijs)

### Plugins

Chai offers a robust Plugin architecture for extending Chai's assertions and interfaces.

- Need a plugin? View the [official plugin list](http://chaijs.com/plugins).
- Have a plugin and want it listed? Open a Pull Request at [chaijs/chai-docs:plugin.js](https://github.com/chaijs/chai-docs/blob/master/plugins.js#L1-L12). 
- Want to build a plugin? Read the [plugin api documentation](http://chaijs.com/guide/plugins/).

### Related Projects

- [chaijs / assertion-error](https://github.com/chaijs/assertion-error): Custom `Error` constructor thrown upon an assertion failing.
- [chaijs / deep-eql](https://github.com/chaijs/deep-eql): Improved deep equality testing for Node.js and the browser.

### Contributors

     project  : chai
     repo age : 2 years, 3 months ago
     commits  : 756
     active   : 170 days
     files    : 57
     authors  :
       540  Jake Luer               71.4%
        79  Veselin Todorov         10.4%
        43  Domenic Denicola        5.7%
         6  Ruben Verborgh          0.8%
         5  George Kats             0.7%
         5  Jo Liss                 0.7%
         5  Juliusz Gonera          0.7%
         5  Scott Nonnenberg        0.7%
         5  leider                  0.7%
         4  John Firebaugh          0.5%
         4  Max Edmands             0.5%
         4  Nick Heiner             0.5%
         4  josher19                0.5%
         3  Andrei Neculau          0.4%
         3  Duncan Beevers          0.4%
         3  Jake Rosoman            0.4%
         3  Jeff Barczewski         0.4%
         3  Ryunosuke SATO          0.4%
         3  Veselin                 0.4%
         2  Bartvds                 0.3%
         2  Edwin Shao              0.3%
         2  Jakub Nešetřil          0.3%
         2  Roman Masek             0.3%
         2  Teddy Cross             0.3%
         1  Anand Patil             0.1%
         1  Benjamin Horsleben      0.1%
         1  Brandon Payton          0.1%
         1  Chris Connelly          0.1%
         1  Chun-Yi                 0.1%
         1  DD                      0.1%
         1  Dido Arellano           0.1%
         1  Jeff Welch              0.1%
         1  Kilian Ciuffolo         0.1%
         1  Luís Cardoso            0.1%
         1  Niklas Närhinen         0.1%
         1  Paul Miller             0.1%
         1  Refael Ackermann        0.1%
         1  Sasha Koss              0.1%
         1  Victor Costan           0.1%
         1  Vinay Pulim             0.1%
         1  Virginie BARDALES       0.1%
         1  laconbass               0.1%
         1  piecioshka              0.1%

## License

(The MIT License)

Copyright (c) 2011-2014 Jake Luer <jake@alogicalparadox.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
